@@ -29,19 +29,19 @@ NULL
 #' character, it must match one of the names in the \code{ModifierSet}.
 #' @param ... optional parameters:
 #' \itemize{
-#' \item{\code{alias}} {a data.frame with two columns, \code{tx_id} and 
-#' \code{name}, to convert transcipt ids to another identifier}
-#' \item{\code{name}} {Limit results to one specific gene or transcript}
-#' \item{\code{sequenceData}} {TRUE or FALSE? Should the aggregate of 
+#' \item \code{alias}: a data.frame with two columns, \code{tx_id} and 
+#' \code{name}, to convert transcipt ids to another identifier
+#' \item \code{name}: Limit results to one specific gene or transcript
+#' \item \code{sequenceData}: TRUE or FALSE? Should the aggregate of 
 #' sequenceData be used for the comparison instead of the aggregate data if each
-#' \code{Modifier} element? (default: \code{sequenceData = FALSE})}
-#' \item{\code{compareType}} {a valid score type to use for the comparison. If
+#' \code{Modifier} element? (default: \code{sequenceData = FALSE})
+#' \item \code{compareType}: a valid score type to use for the comparison. If
 #' \code{sequenceData = FALSE} this defaults to \code{mainScore(x)}, whereas
 #' if \code{sequenceData = TRUE} all columns will be used by setting 
-#' \code{allTypes = TRUE}.}
-#' \item{\code{allTypes}} {TRUE or FALSE? Should all available score be 
-#' compared? (default: \code{allTypes = sequenceData})}
-#' \item{...} {passed on to \code{\link{subsetByCoord}}}
+#' \code{allTypes = TRUE}.
+#' \item \code{allTypes}: TRUE or FALSE? Should all available score be 
+#' compared? (default: \code{allTypes = sequenceData})
+#' \item \code{...}: passed on to \code{\link{subsetByCoord}}
 #' }
 #' 
 #' @return \code{compareByCoord} returns a
@@ -395,13 +395,14 @@ setMethod("compareByCoord",
   do.call(plot_FUN,list(data = data, limits = limits))
 }
 
-#' @importFrom ggplot2 ggplot aes_ geom_raster facet_grid scale_fill_gradientn
+#' @importFrom ggplot2 ggplot aes geom_raster facet_grid scale_fill_gradientn
 #'   scale_y_discrete scale_x_discrete theme_minimal theme element_text
+#' @importFrom ggplot2 .data
 .get_heatmap_plot_compare <- function(data, limits){
   ggplot(data) + 
-    geom_raster(mapping = aes_(x = ~variable,
-                                                 y = ~labels,
-                                                 fill = ~value)) +
+    geom_raster(mapping = aes(x = .data$variable,
+                              y = .data$labels,
+                              fill = .data$value)) +
     facet_grid(names ~ ., scales = "free", space = "free") +
     scale_fill_gradientn(name = "Score",
                                   colours = rev(colorRamps::matlab.like(100)),
@@ -416,16 +417,17 @@ setMethod("compareByCoord",
                    axis.text.x.top = element_text(angle = 30,hjust = 0))
 }
 
-#' @importFrom ggplot2 ggplot aes_ geom_point geom_jitter facet_grid 
+#' @importFrom ggplot2 ggplot aes geom_point geom_jitter facet_grid 
 #'   theme_classic theme scale_x_discrete scale_y_continuous scale_fill_brewer 
 #'   element_text
+#' @importFrom ggplot2 .data
 .get_point_plot_compare <- function(data, limits){
   data$labels <- factor(data$labels, rev(levels(data$labels)))
   ggplot(data) + 
-    geom_point(mapping = aes_(x = ~labels,
-                              y = ~value,
-                              fill = ~variable,
-                              group = ~variable),
+    geom_point(mapping = aes(x = .data$labels,
+                             y = .data$value,
+                             fill = .data$variable,
+                             group = .data$variable),
                shape = 21) + 
     facet_grid(. ~ names, space = "free_x", scales = "free_x") +
     scale_x_discrete(name = "Positions") +
